
# MINTO: Jij Management and Insight tool for Optimization

[![PyPI version shields.io](https://img.shields.io/pypi/v/minto.svg)](https://pypi.python.org/pypi/minto/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/minto.svg)](https://pypi.python.org/pypi/minto/)
[![PyPI implementation](https://img.shields.io/pypi/implementation/minto.svg)](https://pypi.python.org/pypi/minto/)
[![PyPI format](https://img.shields.io/pypi/format/minto.svg)](https://pypi.python.org/pypi/minto/)
[![PyPI license](https://img.shields.io/pypi/l/minto.svg)](https://pypi.python.org/pypi/minto/)
[![PyPI download month](https://img.shields.io/pypi/dm/minto.svg)](https://pypi.python.org/pypi/minto/)
[![Downloads](https://pepy.tech/badge/minto)](https://pepy.tech/project/minto)

[![Python Test](https://github.com/Jij-Inc/minto/actions/workflows/python-test.yml/badge.svg)](https://github.com/Jij-Inc/minto/actions/workflows/python-test.yml)
[![CodeQL](https://github.com/Jij-Inc/minto/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/Jij-Inc/minto/actions/workflows/github-code-scanning/codeql)
[![Upload Python Package](https://github.com/Jij-Inc/minto/actions/workflows/python-publish.yml/badge.svg)](https://github.com/Jij-Inc/minto/actions/workflows/python-publish.yml)
[![codecov](https://codecov.io/gh/Jij-Inc/minto/branch/main/graph/badge.svg?token=pfEmtaSP8Z)](https://codecov.io/gh/Jij-Inc/minto)


`minto` is a Python library designed for developers working on research and development or proof-of-concept experiments using mathematical optimization. Positioned similarly to mlflow in the machine learning field, `minto` provides features such as saving optimization results, automatically computing benchmark metrics, and offering visualization tools for the results.

Primarily supporting Ising optimization problems,  plans to extend its support to a wide range of optimization problems, such as MIP solvers, in the future.

## Installation
`minto` can be easily installed using pip.

``` shell
pip install minto
```

## Documentation and Support

Documentation: https://jij-inc.github.io/minto/

Tutorials will be provided in the future. Stay tuned!


## How to Contribute

See [CONTRIBUITING.md](CONTRIBUTING.md) 

---

Copyright (c) 2023 Jij Inc.

